;*****************************************************************************/
;*  LibreDWG - free implementation of the DWG file format                    */
;*                                                                           */
;*  Copyright (C) 2011 Free Software Foundation, Inc.                        */
;*  Copyright (C) 2011 Guruprasad Rane                                       */
;*                                                                           */
;*  This library is free software, licensed under the terms of the GNU       */
;*  General Public License as published by the Free Software Foundation,     */
;*  either version 3 of the License, or (at your option) any later version.  */
;*  You should have received a copy of the GNU General Public License        */
;*  along with this program.  If not, see <http://www.gnu.org/licenses/>.    */
;*****************************************************************************/
;*
;*
;* dwgtotxt.lsp Version 0.2 Date:8th November 2011
;* written by Guruprasad Rane <raneguruprasad@gmail.com>
;* Disclaimer : This program is distributed without any warrenty. This program
;* plays with autocad log file so better create a back of logfile before using.
;* Description: Converts visible objects or entities from drawing file to text file.
;* Usage: Load the script in Autocad using Tools>Load application. Run the command
;* dwgtotxt in commandline. New text file with the same name as that of drawingfile
;* will be created. Use txttoxml.py to convert text file to xml.
;* Limitations: Information of visible objects that can be selected in
;* selection set and header variables is exported to text file.


(vl-load-com)
(defun DXOutputtxt (obj)						; Function to output data to text file
	(princ "\n<DwgEntity\n")					; Output text necessary for formatting to xml
	(princ obj)							; Output info about the object
	(setq aaa (vlax-dump-object obj))				; Output info about the object
	(princ " />")							; Output text necessary for formatting to xml

)

(defun DXOutputHeaderVariables()

  (princ "<DWGHeaderVariable name='ACADMAINTVER' value='")(princ (getvar 'ACADMAINTVER))(princ "' />\n")
(princ "<DWGHeaderVariable name='ACADVER' value='")(princ (getvar 'ACADVER))(princ "' />\n")
(princ "<DWGHeaderVariable name='ANGBASE' value='")(princ (getvar 'ANGBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='ANGDIR' value='")(princ (getvar 'ANGDIR))(princ "' />\n")
(princ "<DWGHeaderVariable name='ATTMODE' value='")(princ (getvar 'ATTMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='AUNITS' value='")(princ (getvar 'AUNITS))(princ "' />\n")
(princ "<DWGHeaderVariable name='AUPREC' value='")(princ (getvar 'AUPREC))(princ "' />\n")
(princ "<DWGHeaderVariable name='CECOLOR' value='")(princ (getvar 'CECOLOR))(princ "' />\n")
(princ "<DWGHeaderVariable name='CELTSCALE' value='")(princ (getvar 'CELTSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='CELTYPE' value='")(princ (getvar 'CELTYPE))(princ "' />\n")
(princ "<DWGHeaderVariable name='CELWEIGHT' value='")(princ (getvar 'CELWEIGHT))(princ "' />\n")
(princ "<DWGHeaderVariable name='CEPSNID' value='")(princ (getvar 'CEPSNID))(princ "' />\n")
(princ "<DWGHeaderVariable name='CEPSNTYPE' value='")(princ (getvar 'CEPSNTYPE))(princ "' />\n")
(princ "<DWGHeaderVariable name='CHAMFERA' value='")(princ (getvar 'CHAMFERA))(princ "' />\n")
(princ "<DWGHeaderVariable name='CHAMFERB' value='")(princ (getvar 'CHAMFERB))(princ "' />\n")
(princ "<DWGHeaderVariable name='CHAMFERC' value='")(princ (getvar 'CHAMFERC))(princ "' />\n")
(princ "<DWGHeaderVariable name='CHAMFERD' value='")(princ (getvar 'CHAMFERD))(princ "' />\n")
(princ "<DWGHeaderVariable name='CLAYER' value='")(princ (getvar 'CLAYER))(princ "' />\n")
(princ "<DWGHeaderVariable name='CMLJUST' value='")(princ (getvar 'CMLJUST))(princ "' />\n")
(princ "<DWGHeaderVariable name='CMLSCALE' value='")(princ (getvar 'CMLSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='CMLSTYLE' value='")(princ (getvar 'CMLSTYLE))(princ "' />\n")
(princ "<DWGHeaderVariable name='CSHADOW' value='")(princ (getvar 'CSHADOW))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMADEC' value='")(princ (getvar 'DIMADEC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALT' value='")(princ (getvar 'DIMALT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTD' value='")(princ (getvar 'DIMALTD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTF' value='")(princ (getvar 'DIMALTF))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTRND' value='")(princ (getvar 'DIMALTRND))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTTD' value='")(princ (getvar 'DIMALTTD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTTZ' value='")(princ (getvar 'DIMALTTZ))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTU' value='")(princ (getvar 'DIMALTU))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMALTZ' value='")(princ (getvar 'DIMALTZ))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMAPOST' value='")(princ (getvar 'DIMAPOST))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMASO' value='")(princ (getvar 'DIMASO))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMASSOC' value='")(princ (getvar 'DIMASSOC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMASZ' value='")(princ (getvar 'DIMASZ))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMATFIT' value='")(princ (getvar 'DIMATFIT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMAUNIT' value='")(princ (getvar 'DIMAUNIT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMAZIN' value='")(princ (getvar 'DIMAZIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMBLK' value='")(princ (getvar 'DIMBLK))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMBLK1' value='")(princ (getvar 'DIMBLK1))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMBLK2' value='")(princ (getvar 'DIMBLK2))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMCEN' value='")(princ (getvar 'DIMCEN))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMCLRD' value='")(princ (getvar 'DIMCLRD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMCLRE' value='")(princ (getvar 'DIMCLRE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMCLRT' value='")(princ (getvar 'DIMCLRT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMDEC' value='")(princ (getvar 'DIMDEC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMDLE' value='")(princ (getvar 'DIMDLE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMDLI' value='")(princ (getvar 'DIMDLI))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMDSEP' value='")(princ (getvar 'DIMDSEP))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMEXE' value='")(princ (getvar 'DIMEXE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMEXO' value='")(princ (getvar 'DIMEXO))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMFAC' value='")(princ (getvar 'DIMFAC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMGAP' value='")(princ (getvar 'DIMGAP))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMJUST' value='")(princ (getvar 'DIMJUST))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLDRBLK' value='")(princ (getvar 'DIMLDRBLK))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLFAC' value='")(princ (getvar 'DIMLFAC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLIM' value='")(princ (getvar 'DIMLIM))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLUNIT' value='")(princ (getvar 'DIMLUNIT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLWD' value='")(princ (getvar 'DIMLWD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMLWE' value='")(princ (getvar 'DIMLWE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMPOST' value='")(princ (getvar 'DIMPOST))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMRND' value='")(princ (getvar 'DIMRND))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSAH' value='")(princ (getvar 'DIMSAH))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSCALE' value='")(princ (getvar 'DIMSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSD1' value='")(princ (getvar 'DIMSD1))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSD2' value='")(princ (getvar 'DIMSD2))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSE1' value='")(princ (getvar 'DIMSE1))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSE2' value='")(princ (getvar 'DIMSE2))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSHO' value='")(princ (getvar 'DIMSHO))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSOXD' value='")(princ (getvar 'DIMSOXD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMSTYLE' value='")(princ (getvar 'DIMSTYLE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTAD' value='")(princ (getvar 'DIMTAD))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTDEC' value='")(princ (getvar 'DIMTDEC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTFAC' value='")(princ (getvar 'DIMTFAC))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTIH' value='")(princ (getvar 'DIMTIH))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTIX' value='")(princ (getvar 'DIMTIX))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTM' value='")(princ (getvar 'DIMTM))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTMOVE' value='")(princ (getvar 'DIMTMOVE))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTOFL' value='")(princ (getvar 'DIMTOFL))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTOH' value='")(princ (getvar 'DIMTOH))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTOL' value='")(princ (getvar 'DIMTOL))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTOLJ' value='")(princ (getvar 'DIMTOLJ))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTP' value='")(princ (getvar 'DIMTP))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTSZ' value='")(princ (getvar 'DIMTSZ))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTVP' value='")(princ (getvar 'DIMTVP))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTXSTY' value='")(princ (getvar 'DIMTXSTY))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTXT' value='")(princ (getvar 'DIMTXT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMTZIN' value='")(princ (getvar 'DIMTZIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMUPT' value='")(princ (getvar 'DIMUPT))(princ "' />\n")
(princ "<DWGHeaderVariable name='DIMZIN' value='")(princ (getvar 'DIMZIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='DISPSILH' value='")(princ (getvar 'DISPSILH))(princ "' />\n")
(princ "<DWGHeaderVariable name='DRAGVS' value='")(princ (getvar 'DRAGVS))(princ "' />\n")
(princ "<DWGHeaderVariable name='DWGCODEPAGE' value='")(princ (getvar 'DWGCODEPAGE))(princ "' />\n")
(princ "<DWGHeaderVariable name='ELEVATION' value='")(princ (getvar 'ELEVATION))(princ "' />\n")
(princ "<DWGHeaderVariable name='ENDCAPS' value='")(princ (getvar 'ENDCAPS))(princ "' />\n")
(princ "<DWGHeaderVariable name='EXTMAX' value='")(princ (getvar 'EXTMAX))(princ "' />\n")
(princ "<DWGHeaderVariable name='EXTMIN' value='")(princ (getvar 'EXTMIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='EXTNAMES' value='")(princ (getvar 'EXTNAMES))(princ "' />\n")
(princ "<DWGHeaderVariable name='FILLETRAD' value='")(princ (getvar 'FILLETRAD))(princ "' />\n")
(princ "<DWGHeaderVariable name='FILLMODE' value='")(princ (getvar 'FILLMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='FINGERPRINTGUID' value='")(princ (getvar 'FINGERPRINTGUID))(princ "' />\n")
(princ "<DWGHeaderVariable name='HALOGAP' value='")(princ (getvar 'HALOGAP))(princ "' />\n")
(princ "<DWGHeaderVariable name='HANDSEED' value='")(princ (getvar 'HANDSEED))(princ "' />\n")
(princ "<DWGHeaderVariable name='HIDETEXT' value='")(princ (getvar 'HIDETEXT))(princ "' />\n")
(princ "<DWGHeaderVariable name='HYPERLINKBASE' value='")(princ (getvar 'HYPERLINKBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='INDEXCTL' value='")(princ (getvar 'INDEXCTL))(princ "' />\n")
(princ "<DWGHeaderVariable name='INSBASE' value='")(princ (getvar 'INSBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='INSUNITS' value='")(princ (getvar 'INSUNITS))(princ "' />\n")
(princ "<DWGHeaderVariable name='INTERFERECOLOR' value='")(princ (getvar 'INTERFERECOLOR))(princ "' />\n")
(princ "<DWGHeaderVariable name='INTERFEREOBJVS' value='")(princ (getvar 'INTERFEREOBJVS))(princ "' />\n")
(princ "<DWGHeaderVariable name='INTERFEREVPVS' value='")(princ (getvar 'INTERFEREVPVS))(princ "' />\n")
(princ "<DWGHeaderVariable name='INTERSECTIONCOLOR' value='")(princ (getvar 'INTERSECTIONCOLOR))(princ "' />\n")
(princ "<DWGHeaderVariable name='INTERSECTIONDISPLAY' value='")(princ (getvar 'INTERSECTIONDISPLAY))(princ "' />\n")
(princ "<DWGHeaderVariable name='JOINSTYLE' value='")(princ (getvar 'JOINSTYLE))(princ "' />\n")
(princ "<DWGHeaderVariable name='LIMCHECK' value='")(princ (getvar 'LIMCHECK))(princ "' />\n")
(princ "<DWGHeaderVariable name='LIMMAX' value='")(princ (getvar 'LIMMAX))(princ "' />\n")
(princ "<DWGHeaderVariable name='LIMMIN' value='")(princ (getvar 'LIMMIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='LTSCALE' value='")(princ (getvar 'LTSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='LUNITS' value='")(princ (getvar 'LUNITS))(princ "' />\n")
(princ "<DWGHeaderVariable name='LUPREC' value='")(princ (getvar 'LUPREC))(princ "' />\n")
(princ "<DWGHeaderVariable name='LWDISPLAY' value='")(princ (getvar 'LWDISPLAY))(princ "' />\n")
(princ "<DWGHeaderVariable name='MAXACTVP' value='")(princ (getvar 'MAXACTVP))(princ "' />\n")
(princ "<DWGHeaderVariable name='MEASUREMENT' value='")(princ (getvar 'MEASUREMENT))(princ "' />\n")
(princ "<DWGHeaderVariable name='MENU' value='")(princ (getvar 'MENU))(princ "' />\n")
(princ "<DWGHeaderVariable name='MIRRTEXT' value='")(princ (getvar 'MIRRTEXT))(princ "' />\n")
(princ "<DWGHeaderVariable name='OBSCOLOR' value='")(princ (getvar 'OBSCOLOR))(princ "' />\n")
(princ "<DWGHeaderVariable name='OBSLTYPE' value='")(princ (getvar 'OBSLTYPE))(princ "' />\n")
(princ "<DWGHeaderVariable name='ORTHOMODE' value='")(princ (getvar 'ORTHOMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PDMODE' value='")(princ (getvar 'PDMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PDSIZE' value='")(princ (getvar 'PDSIZE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PELEVATION' value='")(princ (getvar 'PELEVATION))(princ "' />\n")
(princ "<DWGHeaderVariable name='PEXTMAX' value='")(princ (getvar 'PEXTMAX))(princ "' />\n")
(princ "<DWGHeaderVariable name='PEXTMIN' value='")(princ (getvar 'PEXTMIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='PINSBASE' value='")(princ (getvar 'PINSBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PLIMCHECK' value='")(princ (getvar 'PLIMCHECK))(princ "' />\n")
(princ "<DWGHeaderVariable name='PLIMMAX' value='")(princ (getvar 'PLIMMAX))(princ "' />\n")
(princ "<DWGHeaderVariable name='PLIMMIN' value='")(princ (getvar 'PLIMMIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='PLINEGEN' value='")(princ (getvar 'PLINEGEN))(princ "' />\n")
(princ "<DWGHeaderVariable name='PLINEWID' value='")(princ (getvar 'PLINEWID))(princ "' />\n")
(princ "<DWGHeaderVariable name='PROJECTNAME' value='")(princ (getvar 'PROJECTNAME))(princ "' />\n")
(princ "<DWGHeaderVariable name='PROXYGRAPHICS' value='")(princ (getvar 'PROXYGRAPHICS))(princ "' />\n")
(princ "<DWGHeaderVariable name='PSLTSCALE' value='")(princ (getvar 'PSLTSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PSTYLEMODE' value='")(princ (getvar 'PSTYLEMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PSVPSCALE' value='")(princ (getvar 'PSVPSCALE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSBASE' value='")(princ (getvar 'PUCSBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSNAME' value='")(princ (getvar 'PUCSNAME))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORG' value='")(princ (getvar 'PUCSORG))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGBACK' value='")(princ (getvar 'PUCSORGBACK))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGBOTTOM' value='")(princ (getvar 'PUCSORGBOTTOM))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGFRONT' value='")(princ (getvar 'PUCSORGFRONT))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGLEFT' value='")(princ (getvar 'PUCSORGLEFT))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGRIGHT' value='")(princ (getvar 'PUCSORGRIGHT))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORGTOP' value='")(princ (getvar 'PUCSORGTOP))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORTHOREF' value='")(princ (getvar 'PUCSORTHOREF))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSORTHOVIEW' value='")(princ (getvar 'PUCSORTHOVIEW))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSXDIR' value='")(princ (getvar 'PUCSXDIR))(princ "' />\n")
(princ "<DWGHeaderVariable name='PUCSYDIR' value='")(princ (getvar 'PUCSYDIR))(princ "' />\n")
(princ "<DWGHeaderVariable name='QTEXTMODE' value='")(princ (getvar 'QTEXTMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='REGENMODE' value='")(princ (getvar 'REGENMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='SHADEDGE' value='")(princ (getvar 'SHADEDGE))(princ "' />\n")
(princ "<DWGHeaderVariable name='SHADEDIF' value='")(princ (getvar 'SHADEDIF))(princ "' />\n")
(princ "<DWGHeaderVariable name='SHADOWPLANELOCATION' value='")(princ (getvar 'SHADOWPLANELOCATION))(princ "' />\n")
(princ "<DWGHeaderVariable name='SKETCHINC' value='")(princ (getvar 'SKETCHINC))(princ "' />\n")
(princ "<DWGHeaderVariable name='SKPOLY' value='")(princ (getvar 'SKPOLY))(princ "' />\n")
(princ "<DWGHeaderVariable name='SORTENTS' value='")(princ (getvar 'SORTENTS))(princ "' />\n")
(princ "<DWGHeaderVariable name='SPLFRAME' value='")(princ (getvar 'SPLFRAME))(princ "' />\n")
(princ "<DWGHeaderVariable name='SPLINESEGS' value='")(princ (getvar 'SPLINESEGS))(princ "' />\n")
(princ "<DWGHeaderVariable name='SPLINETYPE' value='")(princ (getvar 'SPLINETYPE))(princ "' />\n")
(princ "<DWGHeaderVariable name='SURFTAB1' value='")(princ (getvar 'SURFTAB1))(princ "' />\n")
(princ "<DWGHeaderVariable name='SURFTAB2' value='")(princ (getvar 'SURFTAB2))(princ "' />\n")
(princ "<DWGHeaderVariable name='SURFTYPE' value='")(princ (getvar 'SURFTYPE))(princ "' />\n")
(princ "<DWGHeaderVariable name='SURFU' value='")(princ (getvar 'SURFU))(princ "' />\n")
(princ "<DWGHeaderVariable name='SURFV' value='")(princ (getvar 'SURFV))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDCREATE' value='")(princ (getvar 'TDCREATE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDINDWG' value='")(princ (getvar 'TDINDWG))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDUCREATE' value='")(princ (getvar 'TDUCREATE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDUPDATE' value='")(princ (getvar 'TDUPDATE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDUSRTIMER' value='")(princ (getvar 'TDUSRTIMER))(princ "' />\n")
(princ "<DWGHeaderVariable name='TDUUPDATE' value='")(princ (getvar 'TDUUPDATE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TEXTSIZE' value='")(princ (getvar 'TEXTSIZE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TEXTSTYLE' value='")(princ (getvar 'TEXTSTYLE))(princ "' />\n")
(princ "<DWGHeaderVariable name='THICKNESS' value='")(princ (getvar 'THICKNESS))(princ "' />\n")
(princ "<DWGHeaderVariable name='TILEMODE' value='")(princ (getvar 'TILEMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='TRACEWID' value='")(princ (getvar 'TRACEWID))(princ "' />\n")
(princ "<DWGHeaderVariable name='TREEDEPTH' value='")(princ (getvar 'TREEDEPTH))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSBASE' value='")(princ (getvar 'UCSBASE))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSNAME' value='")(princ (getvar 'UCSNAME))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORG' value='")(princ (getvar 'UCSORG))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGBACK' value='")(princ (getvar 'UCSORGBACK))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGBOTTOM' value='")(princ (getvar 'UCSORGBOTTOM))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGFRONT' value='")(princ (getvar 'UCSORGFRONT))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGLEFT' value='")(princ (getvar 'UCSORGLEFT))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGRIGHT' value='")(princ (getvar 'UCSORGRIGHT))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORGTOP' value='")(princ (getvar 'UCSORGTOP))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORTHOREF' value='")(princ (getvar 'UCSORTHOREF))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSORTHOVIEW' value='")(princ (getvar 'UCSORTHOVIEW))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSXDIR' value='")(princ (getvar 'UCSXDIR))(princ "' />\n")
(princ "<DWGHeaderVariable name='UCSYDIR' value='")(princ (getvar 'UCSYDIR))(princ "' />\n")
(princ "<DWGHeaderVariable name='UNITMODE' value='")(princ (getvar 'UNITMODE))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERI1' value='")(princ (getvar 'USERI1))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERI2' value='")(princ (getvar 'USERI2))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERI3' value='")(princ (getvar 'USERI3))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERI4' value='")(princ (getvar 'USERI4))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERI5' value='")(princ (getvar 'USERI5))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERR1' value='")(princ (getvar 'USERR1))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERR2' value='")(princ (getvar 'USERR2))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERR3' value='")(princ (getvar 'USERR3))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERR4' value='")(princ (getvar 'USERR4))(princ "' />\n")
(princ "<DWGHeaderVariable name='USERR5' value='")(princ (getvar 'USERR5))(princ "' />\n")
(princ "<DWGHeaderVariable name='USRTIMER' value='")(princ (getvar 'USRTIMER))(princ "' />\n")
(princ "<DWGHeaderVariable name='VERSIONGUID' value='")(princ (getvar 'VERSIONGUID))(princ "' />\n")
(princ "<DWGHeaderVariable name='VISRETAIN' value='")(princ (getvar 'VISRETAIN))(princ "' />\n")
(princ "<DWGHeaderVariable name='WORLDVIEW' value='")(princ (getvar 'WORLDVIEW))(princ "' />\n")
(princ "<DWGHeaderVariable name='XCLIPFRAME' value='")(princ (getvar 'XCLIPFRAME))(princ "' />\n")
(princ "<DWGHeaderVariable name='XEDIT' value='")(princ (getvar 'XEDIT))(princ "' />\n")
  
)


(defun C:dwgtotxt ()
  	(setq DXDwgname (getvar "DWGNAME"))				; Get Drawing file name.
  	(setq DXDwgpath (getvar "DWGPREFIX"))				; Get drawing file path.
  	(setq tempX(- (strlen DXDwgname) 4))				; Create Temp varialble for length of file name - 4 (4 is for .dwg)
  	(setq tempName (substr DXDwgname 1 tempX))			; Create Temp varialble without ".dwg"
	(setq DXdwgoutputfile (strcat DXDwgpath tempName ".txt"))	; Create Outputfile path and name
	(setq DXlogfile (getvar 'logfilename))				; Get Autocad Log file path and name
	(setq DXbackupfile (strcat DXlogfile  ".bak"))			; Create Autocad Lof file backup path and name
	(vl-file-delete  DXbackupfile)					; Delete backup file if existing
	(vl-file-copy  DXlogfile DXbackupfile)				; Copy Log file to Backup file
	(vl-file-delete  DXlogfile)					; Delete log file
   	(setq DXsel (ssget "x"))					; Select all objects in the drawing file
	(setq DXi 0)							; Create Temp Coutner variable
  	(setvar 'logfilemode 1)					  	; Set Logging option to true. New log file gets created here.
  	(DXOutputHeaderVariables)
	(while (< DXi (sslength DXsel))					; While loop for all objects in selection set
		(setq DXen(ssname DXsel DXi))				; Get Name of object in selection set
		(DXOutputtxt (vlax-ename->vla-object DXen))		; Convert Object name to Object and pass to DXOutputtxt function
	  	(setq DXi(+ DXi 1))					; increase the counter
	)
  	(vl-file-delete  DXdwgoutputfile)				; Delete Text output file is alrady existing
  	(vl-file-copy  DXlogfile DXdwgoutputfile)			; Copy log file to text output file
  	(vl-file-copy  DXbackupfile DXlogfile)				; Copy backup of Log file to Log file.
  	(setvar 'logfilemode 0)						; Set Logginf OFF
)
